==> cometchat-3.0.3.tar.gz: lib/Builders/users_request.dart <==
import 'package:cometchat/Exception/CometChatException.dart';
import 'package:cometchat/models/user.dart';
import 'package:cometchat/utils/constants.dart';
import 'package:flutter/services.dart';

class UsersRequest {
  final int? limit;
  final int? token;
  final String? searchKeyword;
  final bool? hideBlockedUsers;
  final String? role;
  final bool? friendsOnly;
  final List<String>? roles;
  final List<String>? tags;
  final bool? withTags;
  final String? userStatus;
  final int? nextPage;
  final int? totalPages;
  final int? currentPage;
  final bool? inProgress;
  final List<String>? uids;
  bool? init;

  UsersRequest._builder(UsersRequestBuilder builder)
      : limit = builder.limit,
        token = builder.token,
        searchKeyword = builder.searchKeyword,
        hideBlockedUsers = builder.hideBlockedUsers,
        role = builder.role,
        friendsOnly = builder.friendsOnly,
        roles = builder.roles,
        tags = builder.tags,
        withTags = builder.withTags,
        userStatus = builder.userStatus,
        nextPage = builder.nextPage,
        totalPages = builder.totalPages,
        currentPage = builder.currentPage,
        inProgress = builder.inProgress,
        uids = builder.uids,
        init = true;

  Future<List<User>> fetchNext(
      {required Function(List<User> userList)? onSuccess,
      required Function(CometChatException excep)? onError}) async {
    print("inside init uids is  ${this.init} ");

    try {
      final result = await channel.invokeMethod('fetchUsers', {
        'searchTerm': this.searchKeyword,
        'limit': this.limit,
        'hidebloackedUsers': this.hideBlockedUsers,
        'userRoles': this.roles,
        'friendsOnly': this.friendsOnly,
        'tags': this.tags,
        'withTags': this.withTags,
        'init': this.init,
        'userStatus': this.userStatus,
        'uids': this.uids
      });
      // print("Ret res $result");
      final List<User> res = result.map<User>((e) => User.fromMap(e)).toList();
      if (onSuccess != null) {
        onSuccess(res);
      }
      this.init = false;
      return res;
    } on PlatformException catch (platformException) {
      if (onError != null) {
        onError(CometChatException(platformException.code,
            platformException.details, platformException.message));
      }
    } catch (e) {
      throw e;
    }
    return [];
  }
}

class UsersRequestBuilder {
  int? limit;
  int? token;
  String? searchKeyword;
  bool? hideBlockedUsers;
  String? role;
  bool? friendsOnly;
  List<String>? roles;
  List<String>? tags;
  bool? withTags;
  String? userStatus;
  int? nextPage;
  int? totalPages;
  int? currentPage;
  bool? inProgress;
  List<String>? uids;

  UsersRequestBuilder();

  UsersRequest build() {
    return UsersRequest._builder(this);
  }
}

==> cometchat-3.0.5.tar.gz: lib/Builders/users_request.dart <==
import 'package:cometchat/Exception/CometChatException.dart';
import 'package:cometchat/models/user.dart';
import 'package:cometchat/utils/constants.dart';
import 'package:flutter/services.dart';

class UsersRequest {
  final int? limit;
  final int? token;
  final String? searchKeyword;
  final bool? hideBlockedUsers;
  final String? role;
  final bool? friendsOnly;
  final List<String>? roles;
  final List<String>? tags;
  final bool? withTags;
  final String? userStatus;
  final int? nextPage;
  final int? totalPages;
  final int? currentPage;
  final bool? inProgress;
  final List<String>? uids;
  bool? init;

  UsersRequest._builder(UsersRequestBuilder builder)
      : limit = builder.limit,
        token = builder.token,
        searchKeyword = builder.searchKeyword,
        hideBlockedUsers = builder.hideBlockedUsers,
        role = builder.role,
        friendsOnly = builder.friendsOnly,
        roles = builder.roles,
        tags = builder.tags,
        withTags = builder.withTags,
        userStatus = builder.userStatus,
        nextPage = builder.nextPage,
        totalPages = builder.totalPages,
        currentPage = builder.currentPage,
        inProgress = builder.inProgress,
        uids = builder.uids,
        init = true;

  Future<List<User>> fetchNext(
      {required Function(List<User> userList)? onSuccess,
      required Function(CometChatException excep)? onError}) async {
    print("inside init uids is  ${this.init} ");

    try {
      final result = await channel.invokeMethod('fetchUsers', {
        'searchTerm': this.searchKeyword,
        'limit': this.limit,
        'hidebloackedUsers': this.hideBlockedUsers,
        'userRoles': this.roles,
        'friendsOnly': this.friendsOnly,
        'tags': this.tags,
        'withTags': this.withTags,
        'init': this.init,
        'userStatus': this.userStatus,
        'uids': this.uids
      });
      //final List<User> res = result.map<User>((e) => User.fromMap(e)).toList();
      final List<User> res = [];
      if (result != null) {
        for (var _obj in result) {
          try {
            res.add(User.fromMap(_obj));
          } catch (_) {}
        }
      }

      if (onSuccess != null) {
        onSuccess(res);
      }
      this.init = false;
      return res;
    } on PlatformException catch (platformException) {
      if (onError != null) {
        onError(CometChatException(platformException.code,
            platformException.details, platformException.message));
      }
    } catch (e) {
      throw e;
    }
    return [];
  }
}

class UsersRequestBuilder {
  int? limit;
  int? token;
  String? searchKeyword;
  bool? hideBlockedUsers;
  String? role;
  bool? friendsOnly;
  List<String>? roles;
  List<String>? tags;
  bool? withTags;
  String? userStatus;
  int? nextPage;
  int? totalPages;
  int? currentPage;
  bool? inProgress;
  List<String>? uids;

  UsersRequestBuilder();

  UsersRequest build() {
    return UsersRequest._builder(this);
  }
}
